document.addEventListener('DOMContentLoaded', function () {
    const uploadArea = document.getElementById('upload-area');
    const fileInput = document.getElementById('file-input');
    const fileList = document.getElementById('file-list');
    const progressBar = document.getElementById('progress-bar');
    const progressContainer = document.getElementById('progress-container');
    const CHUNK_SIZE = 64 * 1024 * 1024; // 64 Mo

    if (typeof uploadPath === 'undefined') {
        console.error('Chemin de téléchargement non défini. Veuillez vérifier les paramètres.');
        return;
    }

    uploadArea.addEventListener('click', function () {
        fileInput.click();
    });

    uploadArea.addEventListener('dragover', function (e) {
        e.preventDefault();
        uploadArea.classList.add('highlight');
    });

    uploadArea.addEventListener('dragleave', function () {
        uploadArea.classList.remove('highlight');
    });

    uploadArea.addEventListener('drop', function (e) {
        e.preventDefault();
        uploadArea.classList.remove('highlight');
        handleFiles(e.dataTransfer.files);
    });

    fileInput.addEventListener('change', function () {
        handleFiles(fileInput.files);
    });

    function handleFiles(files) {
        progressContainer.style.display = 'block';
        progressBar.style.width = '0%';
        progressBar.textContent = '0%';
        let fileIndex = 0;

        function uploadNextFile() {
            if (fileIndex < files.length) {
                uploadFile(files[fileIndex], function() {
                    fileIndex++;
                    uploadNextFile();
                });
            } else {
                progressContainer.style.display = 'none';
                updateFileList();
            }
        }

        uploadNextFile();
    }

    function uploadFile(file, callback) {
        let start = 0;
        let chunkIndex = 0;
        const totalChunks = Math.ceil(file.size / CHUNK_SIZE);

        function uploadNextChunk() {
            if (start < file.size) {
                const chunk = file.slice(start, start + CHUNK_SIZE);
                const formData = new FormData();
                formData.append('file', chunk);
                formData.append('chunkIndex', chunkIndex);
                formData.append('totalChunks', totalChunks);
                formData.append('fileName', file.name);
                formData.append('uploadPath', uploadPath);

                const xhr = new XMLHttpRequest();
                xhr.open('POST', 'includes/upload.php', true);

                xhr.upload.addEventListener('progress', function (e) {
                    if (e.lengthComputable) {
                        const percentComplete = ((chunkIndex * CHUNK_SIZE + e.loaded) / file.size) * 100;
                        progressBar.style.width = percentComplete + '%';
                        progressBar.textContent = Math.round(percentComplete) + '%';
                    }
                });

                xhr.addEventListener('load', function () {
                    if (xhr.status === 200) {
                        const response = JSON.parse(xhr.responseText);
                        if (response.success) {
                            start += CHUNK_SIZE;
                            chunkIndex++;
                            uploadNextChunk();
                        } else {
                            alert('Erreur lors du téléchargement des fichiers: ' + response.message);
                            progressContainer.style.display = 'none';
                        }
                    } else {
                        alert('Erreur lors du téléchargement des fichiers.');
                        progressContainer.style.display = 'none';
                    }
                });

                xhr.addEventListener('error', function () {
                    alert('Erreur lors du téléchargement des fichiers.');
                    progressContainer.style.display = 'none';
                });

                xhr.send(formData);
            } else {
                uploadedFiles.push({name: file.name, size: file.size});
                callback();
            }
        }

        uploadNextChunk();
    }

    function updateFileList() {
        fileList.innerHTML = '';
        uploadedFiles.forEach(file => {
            let li = document.createElement('li');
            li.textContent = file.name + ' (' + Math.round(file.size / 1024) + ' KB)';
            fileList.appendChild(li);
        });
    }
});
