<?php
require_once 'includes/PDO.php';
require_once 'includes/functions.php';

// Définir le répertoire racine
$rootDir = realpath(__DIR__ . '/../..'); // Parent directory of fs-admin

// Fonction pour récupérer les fichiers et dossiers
function getFilesAndDirectories($dir) {
    $files = [];
    $directories = [];
    $items = scandir($dir);
    foreach ($items as $item) {
        if ($item == '.' || $item == '..' || $item == 'fs-admin') continue;
        $path = $dir . '/' . $item;
        if (is_dir($path)) {
            $directories[] = $path;
        } else {
            $files[] = $path;
        }
    }
    return ['files' => $files, 'directories' => $directories];
}

$allFiles = getFilesAndDirectories($rootDir);

// Ajouter le répertoire racine à la liste des répertoires
$allFiles['directories'][] = $rootDir;
?>


    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/codemirror.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.65.5/theme/monokai.min.css">
    <style>
        .form-container, .editor-container {
            width: 40vw;
            padding: 10px;
        }
        .CodeMirror {
            height: 80vh;
            background-color: white;
        }
        .reference-files {
            margin-top: 10px;
        }
        .reference-file {
            display: inline-block;
            padding: 5px;
            background-color: #f0f0f0;
            margin-right: 5px;
            margin-bottom: 5px;
        }
        .reference-file .remove {
            margin-left: 10px;
            cursor: pointer;
            color: red;
        }
        .success, .error {
            display: none;
            margin-top: 10px;
            padding: 10px;
        }
        .success {
            color: green;
            background-color: #d4edda;
        }
        .error {
            color: red;
            background-color: #f8d7da;
        }
    </style>

    <h1>Créer un nouveau fichier</h1>
    <div class="fs-para card-classic">
        <a href="index.php">[retour]</a><br><br>
        <div class="fs-create">
            <div class="form-container">
                <form id="create-file-form">
                    <label for="file-name">Nom du fichier:</label>
                    <input type="text" id="file-name" name="file-name" required>
                    <br><br>
                    <label for="file-type">Type de fichier:</label>
                    <select id="file-type" name="file-type" required>
                        <option value="php">PHP</option>
                        <option value="css">CSS</option>
                        <option value="js">JavaScript</option>
                        <option value="html">HTML</option>
                        <option value="json">JSON</option>
                        <option value="xps">xps</option>
                        <option value="txt">txt</option>
                        <option value="svg">SVG</option>
                        <option value="xml">xml</option>
                    </select>
                    <br><br>
                    <label for="file-directory">Dossier:</label>
                    <select id="file-directory" name="file-directory">
                        <!-- Options dynamically populated by JS -->
                    </select>
                    <br><br>
                    <label for="reference-files">Fichiers de référence:</label>
                    <select id="reference-files" name="reference-files" multiple>
                        <!-- Options dynamically populated by JS -->
                    </select>
                    <div class="reference-files" id="selected-references">
                        <!-- Selected reference files will appear here -->
                    </div>
                    <br><br>
                    <label for="user-prompt">Prompt utilisateur:</label>
                    <textarea id="user-prompt" name="user-prompt" rows="5" required></textarea>
                    <br><br>
                    <button type="button" class="btn-classic" id="send-request">Envoyer la requête</button>
                </form>
                <div class="success" id="success-message">Fichier créé avec succès!</div>
                <div class="error" id="error-message">Erreur lors de la création du fichier.</div>
            </div>
            <div class="editor-container">
              <textarea id="code-editor" rows="20" cols="80"></textarea><br>
             <button type="button" class="btn-classic" id="create-file-button" style="display:none;">Créer le fichier</button>
         </div>
     </div>
 </div>

 <script>
     document.addEventListener('DOMContentLoaded', function () {
         const rootDir = '<?php echo $rootDir; ?>';
         const allFiles = <?php echo json_encode($allFiles); ?>;
         const fileDirectorySelect = document.getElementById('file-directory');
         const referenceFilesSelect = document.getElementById('reference-files');
         const selectedReferencesDiv = document.getElementById('selected-references');

         // Populate file directories
         allFiles.directories.forEach(dir => {
             const option = document.createElement('option');
             option.value = dir;
             option.textContent = dir;
             fileDirectorySelect.appendChild(option);
         });

         // Populate reference files
         allFiles.files.forEach(file => {
             const option = document.createElement('option');
             option.value = file.replace(rootDir + '/', '');
             option.textContent = file.replace(rootDir + '/', '');
             referenceFilesSelect.appendChild(option);
         });

         // Handle reference file selection
         referenceFilesSelect.addEventListener('change', function () {
             selectedReferencesDiv.innerHTML = '';
             Array.from(referenceFilesSelect.selectedOptions).forEach(option => {
                 const refFileDiv = document.createElement('div');
                 refFileDiv.classList.add('reference-file');
                 refFileDiv.textContent = option.value;
                 const removeSpan = document.createElement('span');
                 removeSpan.classList.add('remove');
                 removeSpan.textContent = '×';
                 removeSpan.addEventListener('click', function () {
                     option.selected = false;
                     refFileDiv.remove();
                 });
                 refFileDiv.appendChild(removeSpan);
                 selectedReferencesDiv.appendChild(refFileDiv);
             });
         });

         // Handle form submission
         document.getElementById('send-request').addEventListener('click', function () {
             const fileName = document.getElementById('file-name').value;
             const fileType = document.getElementById('file-type').value;
             const fileDirectory = document.getElementById('file-directory').value;
             const userPrompt = document.getElementById('user-prompt').value;
             const selectedReferences = Array.from(referenceFilesSelect.selectedOptions).map(option => option.value);

             const formData = new FormData();
             formData.append('fileName', fileName);
             formData.append('fileType', fileType);
             formData.append('fileDirectory', fileDirectory);
             formData.append('userPrompt', userPrompt);
             formData.append('selectedReferences', JSON.stringify(selectedReferences));

             fetch('includes/generate_file.php', {
                 method: 'POST',
                 body: formData
             })
             .then(response => response.json())
             .then(data => {
                 console.log(data);
                 if (data.success) {
                     // Insert content into textarea
                     const textarea = document.getElementById('code-editor');
                     textarea.value = data.content;

                     document.getElementById('create-file-button').style.display = 'block';
                     document.getElementById('success-message').style.display = 'block';
                     document.getElementById('error-message').style.display = 'none';
                 } else {
                     document.getElementById('success-message').style.display = 'none';
                     document.getElementById('error-message').style.display = 'block';
                     document.getElementById('error-message').textContent = data.message;
                 }
             })
             .catch(error => {
                 console.log(error);
                 document.getElementById('success-message').style.display = 'none';
                 document.getElementById('error-message').style.display = 'block';
                 document.getElementById('error-message').textContent = 'Erreur lors de la requête: ' + error.message;
             });
         });

         // Handle final file creation
         document.getElementById('create-file-button').addEventListener('click', function () {
             const fileName = document.getElementById('file-name').value;
             const fileType = document.getElementById('file-type').value;
             const fileDirectory = document.getElementById('file-directory').value;
             const fileContent = document.getElementById('code-editor').value;

             const formData = new FormData();
             formData.append('fileName', fileName);
             formData.append('fileType', fileType);
             formData.append('fileDirectory', fileDirectory);
             formData.append('fileContent', fileContent);

             fetch('includes/creating_file.php', {
                 method: 'POST',
                 body: formData
             })
             .then(response => response.json())
             .then(data => {
                 if (data.success) {
                     alert('Fichier créé avec succès!');
                     window.location.reload();
                 } else {
                     alert('Erreur lors de la création du fichier: ' + data.error);
                 }
             })
             .catch(error => {
                 alert('Erreur lors de la requête: ' + error.message);
             });
         });
     });
 </script>
