<?php

//ini_set('display_errors', 1);
//ini_set('display_startup_errors', 1);
//error_reporting(E_ALL);

require_once 'PDO.php';
require_once 'functions.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $fileName = $_POST['fileName'];
    $fileType = $_POST['fileType'];
    $fileDirectory = $_POST['fileDirectory'];
    $userPrompt = $_POST['userPrompt'];
    $selectedReferences = json_decode($_POST['selectedReferences'] ?? '[]', true);

    // Convert inputs to UTF-8
    $fileName = mb_convert_encoding($fileName, 'UTF-8', 'auto');
    $fileType = mb_convert_encoding($fileType, 'UTF-8', 'auto');
    $fileDirectory = mb_convert_encoding($fileDirectory, 'UTF-8', 'auto');
    $userPrompt = mb_convert_encoding($userPrompt, 'UTF-8', 'auto');

    foreach ($selectedReferences as &$reference) {
        $reference = mb_convert_encoding($reference, 'UTF-8', 'auto');
    }
    unset($reference); // break the reference with the last element

    // Récupérer la clé API depuis la table fs_settings
    $stmt = $pdo->prepare("SELECT gpt_api FROM fs_settings WHERE id = 1 LIMIT 1");
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    if (!$row || empty($row['gpt_api'])) {
        echo json_encode(['success' => false, 'message' => 'Clé API non configurée.']);
        exit;
    }
    $apiKey = $row['gpt_api'];

    // Récupérer le prompt d'introduction depuis la table fs_prompt
    $stmt = $pdo->prepare("SELECT prompt FROM fs_prompt WHERE type = 'pr_intro' LIMIT 1");
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);
    if (!$row || empty($row['prompt'])) {
        echo json_encode(['success' => false, 'message' => 'Prompt d\'introduction non configuré.']);
        exit;
    }
    $introPrompt = mb_convert_encoding($row['prompt'], 'UTF-8', 'auto');

    // Créer le prompt pour l'API ChatGPT
    $prompt = "Génère un fichier $fileType pour le fichier $fileName. N'utilise pas de balise pour indiquer que c'est du code, affiche le code source directment\n";
    foreach ($selectedReferences as $reference) {
        $filePath = realpath($fileDirectory . '/' . $reference);
        if ($filePath && is_readable($filePath)) {
            $fileContent = file_get_contents($filePath);
            $fileContent = mb_convert_encoding($fileContent, 'UTF-8', 'auto');
            $prompt .= "Prends ce fichier (" . basename($filePath) . ") en référence: \n\n";
            $prompt .= $fileContent . "\n\n";
        }
    }
    $prompt .= $userPrompt;

    $endpointUrl = "https://api.openai.com/v1/chat/completions";
    $headerParameters = [
        "Content-Type: application/json",
        "Authorization: Bearer " . $apiKey
    ];
    $bodyParameters = [
        "model" => "gpt-3.5-turbo",
        "messages" => [
            [
                "role" => "system",
                "content" => $introPrompt
            ],
            [
                "role" => "user",
                "content" => $prompt
            ]
        ],
        "max_tokens" => 1000,
        "temperature" => 0.7
    ];

    // Encode body parameters as JSON
    $jsonBody = json_encode($bodyParameters);
    if (json_last_error() !== JSON_ERROR_NONE) {
        echo json_encode(['success' => false, 'message' => 'Erreur d\'encodage JSON: ' . json_last_error_msg()]);
        exit;
    }

    // Initialize cURL session
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $endpointUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headerParameters);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonBody);

    // Execute cURL request
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    $curlError = curl_error($ch);
    curl_close($ch);

    // Check for cURL errors
    if ($response === false) {
        echo json_encode(['success' => false, 'message' => 'Erreur cURL: ' . $curlError]);
        exit;
    }

    // Decode JSON response
    $responseData = json_decode($response, true);

    // Check for JSON decoding errors
    if (json_last_error() !== JSON_ERROR_NONE) {
        echo json_encode(['success' => false, 'message' => 'Erreur JSON: ' . json_last_error_msg() . ' - Réponse brute: ' . $response]);
        exit;
    }

    // Check if response contains the expected data
    if (!isset($responseData['choices'][0]['message']['content']) || !isset($responseData['usage']['total_tokens'])) {
        echo json_encode(['success' => false, 'message' => 'Réponse inattendue de l\'API: ' . json_encode($responseData)]);
        exit;
    }

    // Extract the relevant information
    $assistantContent = $responseData['choices'][0]['message']['content'];
    $usageData = $responseData['usage']['total_tokens'];

    // Prepare the response
    $result = [
        'success' => true,
        'content' => $assistantContent,
        'usage' => $usageData
    ];
    header('Content-Type: application/json');
    echo json_encode($result);
}
?>
